# How-to guides

## For users

```{toctree}
---
maxdepth: 1
---
snek-make.md
run-background-foreground.md
restart.myst.md
load_state_stat_files.md
load_plot_log_data.md
history_points.md
rebuild-nek.md
export-sans-snek5000.myst.md
archive-simulation-data.md
templates.md
```

## For developer of Snek5000 solvers

```{toctree}
---
maxdepth: 1
---
control-fortran-warnings.md
read-write-par-files.md
```
